# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2018-06-11 12:20
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('reviews', '0009_auto_20180611_1145'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='review',
            options={'ordering': ('-display_date',)},
        ),
        migrations.AddField(
            model_name='review',
            name='source',
            field=models.TextField(default='', verbose_name='Source'),
        ),
        migrations.AlterField(
            model_name='review',
            name='highlight',
            field=models.BooleanField(default=False, verbose_name='highlight'),
        ),
        migrations.AlterField(
            model_name='review',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='review_comments', to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
    ]



from django.contrib import admin
from django.contrib.contenttypes.admin import (
    GenericStackedInline, GenericTabularInline
)
from django.utils.translation import gettext_lazy as _

from .models import Review


@admin.register(Review)
class ReviewAdmin(admin.ModelAdmin):
    list_display = ('name', 'email', 'score', 'title', 'content', 'display_date', 'highlight')
    list_filter = ('score', 'highlight')

    fieldsets = (
        (None, {
            'fields': ('active', 'user', 'user_name', 'user_email', 'score', 'title', 'comment', 'display_date', 'highlight')
        }),
        ('Generic foreign key', {
            'description': _('The object connected to the review. This can be empty for a global review.'),
            'fields': ('content_type', 'object_id', )
        }),
    )


class ReviewTabularInlineAdmin(GenericTabularInline):
    model = Review
    extra = 1


class ReviewStackedInlineAdmin(GenericStackedInline):
    model = Review
    extra = 1



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2018-06-11 12:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reviews', '0010_auto_20180611_1420'),
    ]

    operations = [
        migrations.AlterField(
            model_name='review',
            name='source',
            field=models.TextField(blank=True, default='', verbose_name='Source'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-12 14:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reviews', '0002_auto_20170912_1154'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='review',
            name='ip_address',
        ),
    ]
